#
# spec file for package icc-examin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           icc-examin
Version:        0.56
Release:        bp155.3.13
Summary:        ICC profile viewer and colour visualisation
License:        (GPL-2.0-or-later AND SUSE-FLTK) AND BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            http://www.oyranos.org/icc-examin
Source:         %{name}_%{version}.orig.tar.bz2
Patch0:         icc-examin-gcc7.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-core-fix-for-FreeBSD-clang-4.0.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  expat
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liboyranos-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  xorg-x11-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(oyranos)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcm)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
Requires:       oyranos
Requires:       oyranos-monitor
Requires:       oyranos-profile-graph
Requires:       oyranos-ui-fltk
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Recommends:     %{name}-lang
Recommends:     freefont
Recommends:     oyranos-qcmsevents
Obsoletes:      icc_examin <= 0.54
Provides:       icc_examin = %{version}

%description
ICC Examin is a small utility (unix name: iccexamin) for the
purpose of watching the internals of ICC profiles, measurement
data (CGATS), colour samples (named colour profiles), gamut
visualisations (vrml), video card gamma tables (Xorg/XFree86/osX).

%lang_package

%prep
%autosetup -p1

%build
%cmake \
   -DOpenGL_GL_PREFERENCE=GLVND
make %{?_smp_mflags}

%install
%cmake_install
%find_lang icc-examin       # generate a special file list
find %{buildroot} -type f -name "*.ttf" -delete -print
%suse_update_desktop_file -n  iccexamin # some openSUSE magic

%files lang -f %{name}.lang

%files
%license COPYING
%doc AUTHORS ChangeLog.md README.md
%{_bindir}/iccexamin
%{_datadir}/applications/iccexamin.desktop
%{_datadir}/pixmaps/iccexamin.svg
%{_mandir}/man1/iccexamin.1%{?ext_man}

%changelog
* Tue Aug  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with modern compilers:
  * 0001-core-fix-for-FreeBSD-clang-4.0.patch
- Spec cleanup
* Sun Dec  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Fix factory build
* Fri Jul 21 2017 tchvatal@suse.com
- Fix building with gcc7 icc-examin-gcc7.patch
- Switch to upstream %%cmake system directly without wrapper
- Make sure all deps are detected properly
- Switch to lcms2 only and drop lcms1
* Thu Dec 22 2016 ku.b@gmx.de - 0.56
- Update to 0.56
- support -2 and -4 version options
- use oyProfile_FromName() and support ID and wildcard loading
- switch to cmake build system
- support Hi-DPI monitors on Linux and OS X
- do not touch observed files (automatic ID calculation)
- fix lots of clang compile warnings
- fix compiling with newer ColorSync
- improve config GUI detection (Synnefo)
* Mon Jan 19 2015 p.drouand@gmail.com
- Large specfile cleanup
- Remove obsolete conditional macros
- Remove depreciated AUTHORS section
- Remove useless lib* requirements as devel packages already need them
  * xorg-x11, xorg-x11-libXext, xorg-x11-libXpm, libXrender
- Remove unneeded dependencies
  * gcc, Mesa, gettext, xorg-x11-devel, xorg-x11-fonts-devel,
    xorg-x11-libICE, xorg-x11-libICE-devel, xorg-x11-libSM,
    xorg-x11-libSM-devel, xorg-x11-libX11, xorg-x11-libXau,
    xorg-x11-libXau-devel, xorg-x11-libXdmcp, xorg-x11-libXdmcp-devel,
    xorg-x11-libXext, xorg-x11-libXfixes, xorg-x11-libXfixes-devel,
    xorg-x11-libXmu, xorg-x11-libXmu-devel, xorg-x11-libXp,
    xorg-x11-libXp-devel, xorg-x11-libXprintUtil,
    xorg-x11-libXprintUtil-devel, xorg-x11-libXt, xorg-x11-libXt-devel,
    xorg-x11-libXv, xorg-x11-libXv-devel, xorg-x11-libfontenc,
    xorg-x11-libfontenc-devel, xorg-x11-libs, xorg-x11-libxkbfile,
    xorg-x11-libxkbfile-devel, xorg-x11-proto-devel, xorg-x11-util-devel,
    xorg-x11-xtrans-devel
- Split out translation files
* Thu May 15 2014 ku.b@gmx.de
- require oyranos and oy-profile-graph
* Thu May 15 2014 ku.b@gmx.de
- add Obsoletes and Privides for move from icc_examin to icc-examin
* Wed May 14 2014 ku.b@gmx.de
- spec clean up:
  + remove mandriva_version section
  + merge old suse_version section
  + run spec-cleaner
* Sat May 10 2014 ku.b@gmx.de - 0.55
- release 0.55
- update to Oyranos 0.9.5 API changes
- adapt inline sed usage for FreeBSD (Boris Samorodov)
- fix build on Factory - where 'pkg-config --cflags xcm' is empty (Dominique Leuenberger)
- fix for profiles without desc tag
- fix lagging UI on file open
- fix Harald's crash on XFCE
- use available XRandR for monitor gamma
* Mon Apr 22 2013 dimstar@opensuse.org
- Add icc_examin-xcm-detection.patch: fix XCM Detection: the
  original test fails if pkg-config --cflags xcm does not return
  any special flags to be added. Additionally, the original version
  check was just wrong anyway.
* Sat Jan 19 2013 ku.b@gmx.de
- release 0.54
- fix warnings with Xcm
* Fri Jan 11 2013 ku.b@gmx.de
- minor bug fixes
* Fri Dec 21 2012 ku.b@gmx.de
- release 0.53
- remove recommendation to oy-monitor-nvidia
- fix compiling on Fedora 17
- rename FLTK functions to internal names
- use editing space only with colour server
- remove debian section in spec file
* Thu Nov  1 2012 ku.b@gmx.de
- release 0.52
- requires Oyranos 0.9.0
- adds -g options
- extracts and displays ICC profiles from Oyranos supported images
- show 2D graph by oyranos-profile-graph
- fix for negative signed chromaticities
- fix mAB/mBA table access
* Thu Sep 20 2012 coolo@suse.com
- add explicit buildrequire on pkgconfig(glu)
* Fri Mar  9 2012 ku.b@gmx.de - 0.51
- release 0.51
* Mon Mar  5 2012 ku.b@gmx.de - 0.51
- test 0.51  git #90c55f1a
* Tue Feb 28 2012 ku.b@gmx.de - 0.51
- test 0.51
* Mon Dec 12 2011 ku.b@gmx.de
- Confirm licensing of icc_examin 0.50  as in bnc#736150
* Sun Dec  4 2011 coolo@suse.com
- add buildrequire libtool
* Thu Sep 22 2011 ku.b@gmx.de
- new release with various fixes and update to oyranos-0.3.2
* Thu Aug 18 2011 toganm@opensuse.org
- spec cleanup
  +add freefont to requires
  +build with %%optflags
  Wed Mar 11 2009 Kai-Uwe Behrmann
- add icc_examin.svg
  Thu Dec 11 2008 Kai-Uwe Behrmann
- add CinéPaint plug-in
- add Oyranos dependencies
  Mon Mar 02 2006 Kai-Uwe Behrmann
- name-majorversion.minorversion-releaseversion.xxx sheme
  Fri Aug 12 2005 Kai-Uwe Behrmann
- GUI improvements
  Tue May 26 2005 Kai-Uwe Behrmann
- GUI improvements
- translation to german in v0.30
  Tue Apr 21 2005 Kai-Uwe Behrmann
- first release
